@@ -1,12 +1,13 @@
 # Give an argument to use stdin, stdout instead of console
 # If argument starts with /dev, use it as console
+# If argument is '--no-print', do not print the result.
+
 BEGIN{ $ENV{PERL_RL} = 'Perl' };	# Do not test TR::Gnu !
 use Term::ReadLine;
 
 use Carp;
 $SIG{__WARN__} = sub { warn Carp::longmess(@_) };
 
-
 if (!@ARGV) {
   $term = new Term::ReadLine 'Simple Perl calc';
 } elsif ($ARGV[0] =~ m|^/dev|) {
@@ -15,6 +16,7 @@ if (!@ARGV) {
   $term = new Term::ReadLine 'Simple Perl calc', \*IN, \*OUT;
 } else {
   $term = new Term::ReadLine 'Simple Perl calc', \*STDIN, \*STDOUT;
+  $no_print = $ARGV[0] eq '--no-print';
 }
 $prompt = "Enter arithmetic or Perl expression: ";
 $OUT = $term->OUT || STDOUT;
@@ -26,10 +28,11 @@ if (%features) {
 } else {
   print $OUT "No additional features present.\n";
 }
+print $OUT "Flipping rl_default_selected each line.\n";
 while ( defined ($_ = $term->readline($prompt, "exit")) ) {
   $res = eval($_);
   warn $@ if $@;
-  print $OUT $res, "\n" unless $@;
+  print $OUT $res, "\n" unless $@ or $no_print;
   $term->addhistory($_) if /\S/ and !$features{autohistory};
+  $readline::rl_default_selected = !$readline::rl_default_selected;
 }
-
